@@ -6,7 +6,7 @@ define([
     , './optionInput.js'
     , './optionSelectBox.js'
     , './vpLineNumberTextArea_apiblock.js'
-    , './optionButton_type2.js'
+
 ], function ( MakeOptionContainer
               , MakeOptionDeleteButton
               , MakeOptionPlusButton
@@ -14,7 +14,7 @@ define([
               , MakeOptionInput
               , MakeOptionSelectBox
               , MakeLineNumberTextArea_apiblock
-              , MakeOptionButton_type2
+
             ) {
 
     return {
@@ -25,6 +25,6 @@ define([
         , MakeOptionInput
         , MakeOptionSelectBox
         , MakeLineNumberTextArea_apiblock
-        , MakeOptionButton_type2
+
     }
 });
