@@ -1,19 +1,10 @@
 define([
     'jquery'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    , 'nbextensions/visualpython/src/common/constant'
     , 'nbextensions/visualpython/src/common/StringBuilder'
-
-    , 'nbextensions/visualpython/src/common/vpFuncJS'
-    , 'nbextensions/visualpython/src/pandas/common/commonPandas'
-    , 'nbextensions/visualpython/src/common/vpMakeDom'
-
-    , '../../api.js'    
+    
     , '../../constData.js'
     
-], function ( $, vpCommon, vpConst, sb, 
-              vpFuncJS, libPandas, vpMakeDom,
-              api, constData ) {
+], function ( $, sb, constData ) {
 
     const { VP_CLASS_STYLE_FLEX_COLUMN_CENTER } = constData;
 
