@@ -1,19 +1,9 @@
 define([
     'jquery'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    , 'nbextensions/visualpython/src/common/constant'
+
     , 'nbextensions/visualpython/src/common/StringBuilder'
-
-    , 'nbextensions/visualpython/src/common/vpFuncJS'
-    , 'nbextensions/visualpython/src/pandas/common/commonPandas'
-    , 'nbextensions/visualpython/src/common/vpMakeDom'
-
-    , '../../api.js'    
-    , '../../constData.js'
     
-], function ( $, vpCommon, vpConst, sb, 
-              vpFuncJS, libPandas, vpMakeDom,
-              api, constData ) {
+], function ( $, sb) {
 
     var MakeOptionPlusButton = function(id, title, className) {
         var sbOptionPlusButton = new sb.StringBuilder();
