@@ -1,41 +1,19 @@
 define([
     'jquery'
-    , 'nbextensions/visualpython/src/common/vpCommon'
-    , 'nbextensions/visualpython/src/common/constant'
+
     , 'nbextensions/visualpython/src/common/StringBuilder'
 
     , '../../api.js'    
-    , '../../config.js'
     , '../../constData.js'
-    , '../../blockRenderer.js'
     , '../base/index.js'
 
-], function ( $, vpCommon, vpConst, sb, 
-                api, config, constData, blockRenderer, baseComponent ) {
-    const { ChangeOldToNewState
-        , FindStateValue
-
-        , CreateOneArrayValueAndGet
-        , UpdateOneArrayValueAndGet
-        , DeleteOneArrayValueAndGet
-
-        , DestructureFromBlockArray
-
-        , MakeFirstCharToUpperCase
-        , MapTypeToName
-        , RemoveSomeBlockAndGetBlockList
-        , ShuffleArray
-        , GetImageUrl
-        , ControlToggleInput } = api;
-
-    const { PROCESS_MODE } = config;
-
-    const { GenerateForParam
-            , GenerateListforConditionList  } = blockRenderer;
+], function ( $, sb, 
+                api, constData, baseComponent ) {
+                    
+    const { GenerateForCode
+            , GenerateListforConditionList } = api;
              
-    const { BLOCK_CODELINE_BTN_TYPE
-            , BLOCK_CODELINE_TYPE
-            , FOR_BLOCK_TYPE
+    const { FOR_BLOCK_TYPE
             , FOR_BLOCK_ARG3_TYPE
             , FOR_BLOCK_SELECT_VALUE_ARG_TYPE
 
@@ -55,54 +33,21 @@ define([
 
             , VP_CLASS_APIBLOCK_OPTION_NAME
             , VP_CLASS_APIBLOCK_BLOCK_HEADER
-
-            , VP_CLASS_STYLE_FLEX_ROW
-            , VP_CLASS_STYLE_FLEX_ROW_CENTER
-            , VP_CLASS_STYLE_FLEX_ROW_WRAP
-            , VP_CLASS_STYLE_FLEX_ROW_CENTER_WRAP
             , VP_CLASS_STYLE_FLEX_ROW_BETWEEN
-            , VP_CLASS_STYLE_FLEX_ROW_AROUND
-            , VP_CLASS_STYLE_FLEX_ROW_EVENLY
-            , VP_CLASS_STYLE_FLEX_ROW_BETWEEN_WRAP
-            , VP_CLASS_STYLE_FLEX_ROW_END
-            , VP_CLASS_STYLE_FLEX_COLUMN
             , VP_CLASS_STYLE_FLEX_COLUMN_CENTER
-            , VP_CLASS_STYLE_FLEX_COLUMN_CENTER_WRAP
-            , VP_CLASS_STYLE_MARGIN_TOP_5PX
 
-
-            , VP_CLASS_STYLE_WIDTH_5PERCENT
-            , VP_CLASS_STYLE_WIDTH_10PERCENT
-            , VP_CLASS_STYLE_WIDTH_15PERCENT
             , VP_CLASS_STYLE_WIDTH_20PERCENT
-            , VP_CLASS_STYLE_WIDTH_25PERCENT
-            , VP_CLASS_STYLE_WIDTH_30PERCENT
-            , VP_CLASS_STYLE_WIDTH_35PERCENT
             , VP_CLASS_STYLE_WIDTH_40PERCENT
-            , VP_CLASS_STYLE_WIDTH_45PERCENT
-            , VP_CLASS_STYLE_WIDTH_50PERCENT
-            , VP_CLASS_STYLE_WIDTH_55PERCENT
-            , VP_CLASS_STYLE_WIDTH_60PERCENT
-            , VP_CLASS_STYLE_WIDTH_65PERCENT
-            , VP_CLASS_STYLE_WIDTH_70PERCENT
-            , VP_CLASS_STYLE_WIDTH_75PERCENT
             , VP_CLASS_STYLE_WIDTH_80PERCENT
-            , VP_CLASS_STYLE_WIDTH_85PERCENT
-            , VP_CLASS_STYLE_WIDTH_90PERCENT
-            , VP_CLASS_STYLE_WIDTH_95PERCENT
             , VP_CLASS_STYLE_WIDTH_100PERCENT
 
-            , VP_CLASS_APIBLOCK_OPTION_INPUT
-
             , VP_CLASS_STYLE_OPACITY_0
             , VP_CLASS_STYLE_OPACITY_1
 
-            , STR_NULL
+            , STR_EMPTY
             , STR_COLON_SELECTED
-            , STR_FOR
             , STR_CHANGE
             , STR_CHANGE_KEYUP_PASTE
-            , STR_SELECTED
             , STR_STRONG
             , STR_FLEX
             , STR_NONE
@@ -114,31 +59,26 @@ define([
             , STATE_forBlockOptionType } = constData;
 
     const { MakeOptionContainer
-            , MakeOptionDeleteButton
-            , MakeOptionPlusButton
-            , MakeVpSuggestInputText_apiblock
-            , MakeOptionInput
-            , MakeOptionSelectBox } = baseComponent;    
+            , MakeVpSuggestInputText_apiblock } = baseComponent;    
 
-    var InitForBlockOption = function(thatBlock, optionPageSelector) {
-        var uuid = thatBlock.getUUID();
-        var blockContainerThis = thatBlock.getBlockContainerThis();
+    var InitForBlockOption = function(thisBlock, optionPageSelector) {
+        var uuid = thisBlock.getUUID();
+        var blockContainerThis = thisBlock.getBlockContainerThis();
 
         /**
          * @event_function
          * for arg1 변경 
          */
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_1 + uuid);
-        $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_1 + uuid, function(event) {
-             // RenderInputRequiredColor(this);           
-            var forParam = thatBlock.getState(STATE_forParam);
-            thatBlock.setState({
+        $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_1 + uuid, function(event) {         
+            var forParam = thisBlock.getState(STATE_forParam);
+            thisBlock.setState({
                 [STATE_forParam]: {
                     ...forParam
                     , arg1 : $(this).val()
                 }
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
 
             event.stopPropagation();
@@ -150,15 +90,14 @@ define([
          */
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_2 + uuid);
         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_2 + uuid, function(event) {
-             // RenderInputRequiredColor(this);
-            var forParam = thatBlock.getState(STATE_forParam);
-            thatBlock.setState({
+            var forParam = thisBlock.getState(STATE_forParam);
+            thisBlock.setState({
                 [STATE_forParam]: {
                     ...forParam
                     , arg2 :  $(this).val()
                 }
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
 
             event.stopPropagation();
@@ -171,31 +110,33 @@ define([
     
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid);
         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid, function(event) {
-             // RenderInputRequiredColor(this);
-            var forParam = thatBlock.getState(STATE_forParam);
-            thatBlock.setState({
+            var forParam = thisBlock.getState(STATE_forParam);
+            thisBlock.setState({
                 [STATE_forParam]: {
                     ...forParam
                     , arg3 :  $(this).val()
                 }
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
 
+            if ($(this).val() == STR_EMPTY) {
+                blockContainerThis.renderBlockOptionTab();
+            }
+  
             event.stopPropagation();
         });
 
         $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid);
         $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid, function(event) {
-             // RenderInputRequiredColor(this);
-            var forParam = thatBlock.getState(STATE_forParam);
-            thatBlock.setState({
+            var forParam = thisBlock.getState(STATE_forParam);
+            thisBlock.setState({
                 [STATE_forParam]: {
                     ...forParam
                     , arg3 :  $(STR_COLON_SELECTED, this).val()  
                 }
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
             blockContainerThis.renderBlockOptionTab();
             event.stopPropagation();
@@ -208,15 +149,14 @@ define([
          */
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_4 + uuid);
         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_4 + uuid, function(event) {
-            // RenderInputRequiredColor(this);
-            var forParam = thatBlock.getState(STATE_forParam);
-            thatBlock.setState({
+            var forParam = thisBlock.getState(STATE_forParam);
+            thisBlock.setState({
                 [STATE_forParam]: {
                     ...forParam
                     , arg4 : $(this).val()
                 }
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
 
             event.stopPropagation();
@@ -229,15 +169,14 @@ define([
          */
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_5 + uuid);
         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_5 + uuid, function(event) {
-            // RenderInputRequiredColor(this);
-            var forParam = thatBlock.getState(STATE_forParam);
-            thatBlock.setState({
+            var forParam = thisBlock.getState(STATE_forParam);
+            thisBlock.setState({
                 [STATE_forParam]: {
                     ...forParam
                     , arg5 : $(this).val()
                 }
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
 
             event.stopPropagation();
@@ -250,15 +189,14 @@ define([
          */
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_6 + uuid);
         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_6 + uuid, function(event) {
-            // RenderInputRequiredColor(this);
-            var forParam = thatBlock.getState(STATE_forParam);
-            thatBlock.setState({
+            var forParam = thisBlock.getState(STATE_forParam);
+            thisBlock.setState({
                 [STATE_forParam]: {
                     ...forParam
                     , arg6 : $(this).val()
                 }
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
             
             event.stopPropagation();
@@ -271,15 +209,14 @@ define([
          */
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_7 + uuid);
         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_7 + uuid, function(event) {
-              // RenderInputRequiredColor(this);
-            var forParam = thatBlock.getState(STATE_forParam);
-            thatBlock.setState({
+            var forParam = thisBlock.getState(STATE_forParam);
+            thisBlock.setState({
                 [STATE_forParam]: {
                     ...forParam
                     , arg7 : $(this).val() 
                 }
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
 
             event.stopPropagation();
@@ -290,15 +227,14 @@ define([
          */
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3_INPUT_STR + uuid);
         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3_INPUT_STR + uuid, function(event) {
-            // RenderInputRequiredColor(this);
-            var forParam = thatBlock.getState(STATE_forParam);
-            thatBlock.setState({
+            var forParam = thisBlock.getState(STATE_forParam);
+            thisBlock.setState({
                 [STATE_forParam]: {
                     ...forParam
                     , arg3InputStr: $(this).val() 
                 }
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
 
             event.stopPropagation();
@@ -309,15 +245,14 @@ define([
          */
         $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3_DEFAULT + uuid);
         $(document).on(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3_DEFAULT + uuid, function(event) {
-            // RenderInputRequiredColor(this);
-            var forParam = thatBlock.getState(STATE_forParam);
-            thatBlock.setState({
+            var forParam = thisBlock.getState(STATE_forParam);
+            thisBlock.setState({
                 [STATE_forParam]: {
                     ...forParam
                     , arg3Default: $(this).val() 
                 }
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
 
             event.stopPropagation();
@@ -329,21 +264,21 @@ define([
          */
         $(document).off(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_TYPE_SELECT + uuid);
         $(document).on(STR_CHANGE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_TYPE_SELECT + uuid, function(event) {
-            // RenderInputRequiredColor(this);
+    
             var selectedVal = $(STR_COLON_SELECTED, this).val();
-            thatBlock.setState({
+            thisBlock.setState({
                 [STATE_forBlockOptionType]: $(STR_COLON_SELECTED, this).val()
             });
 
-            var forParamStr = STR_NULL;
+            var forParamStr = STR_EMPTY;
             if ( selectedVal == FOR_BLOCK_TYPE.FOR ) {
-                forParamStr = GenerateForParam(thatBlock);
+                forParamStr = GenerateForCode(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
-                thatBlock.getBlockHeaderDom().find(STR_STRONG).css(STR_DISPLAY, STR_FLEX);
+                thisBlock.getBlockHeaderDom().find(STR_STRONG).css(STR_DISPLAY, STR_FLEX);
             } else {
-                forParamStr = GenerateListforConditionList(thatBlock);
+                forParamStr = GenerateListforConditionList(thisBlock);
                 $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
-                thatBlock.getBlockHeaderDom().find(STR_STRONG).css(STR_DISPLAY, STR_NONE);
+                thisBlock.getBlockHeaderDom().find(STR_STRONG).css(STR_DISPLAY, STR_NONE);
             }
 
             blockContainerThis.renderBlockOptionTab();
@@ -352,7 +287,7 @@ define([
         });
 
         var bindSelectValueEventFunc_for = function(selectedValue, argType) {
-            var forParam = thatBlock.getState(STATE_forParam);
+            var forParam = thisBlock.getState(STATE_forParam);
 
             var updatedValue;
         
@@ -403,21 +338,20 @@ define([
                 }
             }
 
-            thatBlock.setState({
+            thisBlock.setState({
                 [STATE_forParam]: updatedValue
             });
-            var forParamStr = GenerateForParam(thatBlock);
+            var forParamStr = GenerateForCode(thisBlock);
             $(VP_CLASS_PREFIX + VP_CLASS_APIBLOCK_BLOCK_HEADER + uuid).html(forParamStr);
 
             if (FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3 == argType) {
-            //     $(document).off(STR_CHANGE_KEYUP_PASTE, VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid);
                 blockContainerThis.renderBlockOptionTab();
             }
         }
         
         /** For option 렌더링 */
         var renderThisComponent = function() {
-            var optionContainerDom = MakeOptionContainer();
+            var optionContainerDom = MakeOptionContainer(thisBlock);
             var loadedVariableNameList = blockContainerThis.getKernelLoadedVariableNameList();
             var loadedVariableNameList_arg1 = [ ...loadedVariableNameList,  `vp_i`];
             var loadedVariableNameList_arg4 = [ ...loadedVariableNameList,  `vp_j`];
@@ -432,37 +366,9 @@ define([
             /* ------------- For html dom 생성 ------------------ */
 
             /** For Type 설정 */
-            var forName = STR_FOR;
-            var forBlockOptionType = thatBlock.getState(STATE_forBlockOptionType);
-
-            var selectedFor = forBlockOptionType == FOR_BLOCK_TYPE.FOR 
-                                    ? STR_SELECTED 
-                                    : STR_NULL;
-            var selectedListfor = forBlockOptionType == FOR_BLOCK_TYPE.LIST_FOR
-                                    ? STR_SELECTED 
-                                    : STR_NULL;  
-            var sbforNameSelectType = new sb.StringBuilder();
-            sbforNameSelectType.appendFormatLine("<div class='{0} {1}'>", VP_CLASS_STYLE_FLEX_ROW_END, VP_CLASS_STYLE_MARGIN_TOP_5PX);
-            sbforNameSelectType.appendFormatLine("<div class='{0}'>", 'vp-apiblock-tab-navigation-node-block-title');
-
-            sbforNameSelectType.appendFormatLine("<select id='{0}'>", VP_ID_APIBLOCK_OPTION_FOR_TYPE_SELECT + uuid);
-            sbforNameSelectType.appendFormatLine("<option value='{0}' '{1}'>", STR_FOR, selectedFor);
-            sbforNameSelectType.appendFormatLine("{0}", STR_FOR);
-            sbforNameSelectType.appendLine("</option>");
-            sbforNameSelectType.appendFormatLine("<option value='{0}' '{1}'>", 'listfor', selectedListfor);
-            sbforNameSelectType.appendFormatLine("{0}", 'listfor');
-            sbforNameSelectType.appendLine("</option>");
-            sbforNameSelectType.appendLine("</select>");
-            sbforNameSelectType.appendLine("</div>");
-            sbforNameSelectType.appendLine("</div>");
-            optionContainerDom.append(sbforNameSelectType.toString());
-    
-
-            var forParamState = thatBlock.getState(STATE_forParam);  
+            var forParamState = thisBlock.getState(STATE_forParam);  
 
             const { arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg3Default, arg3InputStr } = forParamState;
-            
-            // console.log('arg3',arg3);
 
             var sbforParam = new sb.StringBuilder();
             sbforParam.appendFormatLine("<div class='{0}' style='{1}'>", VP_CLASS_STYLE_FLEX_ROW_BETWEEN, 
@@ -480,10 +386,7 @@ define([
 
             var sbforVariable = new sb.StringBuilder();
             sbforVariable.appendFormatLine("<div class='{0} {1}'>", VP_CLASS_STYLE_FLEX_ROW_BETWEEN 
-                                                                        , VP_CLASS_STYLE_WIDTH_80PERCENT);
-
-       
-
+                                                                  , VP_CLASS_STYLE_WIDTH_80PERCENT);
             /** For arg1 */
             var sbforParamArg1Input = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_1 + uuid
                                                                     ,arg1
@@ -495,7 +398,6 @@ define([
                                                                             FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG1);
                                                                     });
 
-        
             sbforVariable.appendLine(sbforParamArg1Input);
             var sbforParamArg1Input4 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_4 + uuid
                                                                         ,arg4
@@ -507,7 +409,6 @@ define([
                                                                                 FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG4);
                                                                         });
 
-
             sbforVariable.appendLine(sbforParamArg1Input4);
             sbforVariable.appendLine("</div>");
             $sbforParamDom1.append(sbforVariable.toString());
@@ -540,78 +441,8 @@ define([
                                                                     bindSelectValueEventFunc_for(selectedValue, 
                                                                         FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3);
                                                                 });    
-            // var sbforParamArg3 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid
-            //                                                         , arg3
-            //                                                         , loadedVariableNameList_arg3
-            //                                                         , VP_CLASS_STYLE_WIDTH_40PERCENT
-            //                                                         , 'Method'
-            //                                                         , function(selectedValue) {
-            //                                                             bindSelectValueEventFunc_for(selectedValue, 
-            //                                                                 FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3);
-            //                                                         });                
-            // var sbforParamArg2;
-            // if (arg3 == FOR_BLOCK_ARG3_TYPE.ZIP 
-            //     || arg3 == FOR_BLOCK_ARG3_TYPE.RANGE 
-            //     || arg3 == FOR_BLOCK_ARG3_TYPE.ENUMERATE) {
 
-            // } else {
-            //     sbforParamArg2 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_2 + uuid
-            //                                                         ,arg2
-            //                                                         ,loadedVariableNameList_arg2
-            //                                                         , VP_CLASS_STYLE_WIDTH_40PERCENT
-            //                                                         , STR_VALUE
-            //                                                         , function(selectedValue) {
-            //                                                             bindSelectValueEventFunc_for(selectedValue, 
-            //                                                                 FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2);
-            //                                                         });
-            // }
-            sbforArgContainer.appendLine(sbforParamArg3);
-            // sbforArgContainer.appendLine(sbforParamArg2);
-            // if (arg3 == FOR_BLOCK_ARG3_TYPE.ZIP 
-            //     || arg3 == FOR_BLOCK_ARG3_TYPE.RANGE 
-            //     || arg3 == FOR_BLOCK_ARG3_TYPE.ENUMERATE) {
-            //         sbforParamArg3 = MakeOptionSelectBox(VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid
-            //                                             , VP_CLASS_STYLE_WIDTH_40PERCENT
-            //                                             , arg3
-            //                                             , loadedVariableNameList_arg3);
-            //         sbforArgContainer.appendLine(sbforParamArg3);
-            // } else {
-    
-            //     sbforParamArg3 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid
-            //                                                         , arg3
-            //                                                         , loadedVariableNameList_arg3
-            //                                                         , VP_CLASS_STYLE_WIDTH_40PERCENT
-            //                                                         , 'Method'
-            //                                                         , function(selectedValue) {
-            //                                                             bindSelectValueEventFunc_for(selectedValue, 
-            //                                                                 FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3);
-            //                                                         });                
-
-            //     var sbforParamArg2 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_2 + uuid
-            //                                                             ,arg2
-            //                                                             ,loadedVariableNameList_arg2
-            //                                                             , VP_CLASS_STYLE_WIDTH_40PERCENT
-            //                                                             , STR_VALUE
-            //                                                             , function(selectedValue) {
-            //                                                                 bindSelectValueEventFunc_for(selectedValue, 
-            //                                                                     FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2);
-            //                                                             });
-            //     // sbforArgContainer.appendLine(sbforParamArg2);
-
-            //     sbforArgContainer.appendLine(sbforParamArg3);
-            //     sbforArgContainer.appendLine(sbforParamArg2);                       
-            // }
-            
-                // var sbforParamArg3InputStr = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_3_INPUT_STR + uuid
-                //     , arg3InputStr
-                //     , loadedVariableNameList_arg7
-                //     , VP_CLASS_STYLE_WIDTH_40PERCENT
-                //     , STR_VALUE
-                //     , function(selectedValue) {
-                //         bindSelectValueEventFunc_for(selectedValue, 
-                //             FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3_INPUT_STR);
-                //     });
-                // sbforArgContainer.appendLine(sbforParamArg3InputStr);             
+            sbforArgContainer.appendLine(sbforParamArg3);             
 
             if (arg3 == FOR_BLOCK_ARG3_TYPE.RANGE) {
                 var sbforParamArg5 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_5 + uuid
@@ -626,21 +457,22 @@ define([
                 sbforArgContainer.appendLine(sbforParamArg5);
             }            
 
-            if (arg3 == STR_NULL
+            if (arg3 == STR_EMPTY
                 || arg3 == FOR_BLOCK_ARG3_TYPE.ZIP 
                 || arg3 == FOR_BLOCK_ARG3_TYPE.RANGE 
                 || arg3 == FOR_BLOCK_ARG3_TYPE.ENUMERATE) {
                 var sbforParamArg2 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_2 + uuid
-                                                                        ,arg2
-                                                                        ,loadedVariableNameList_arg2
-                                                                        , VP_CLASS_STYLE_WIDTH_20PERCENT
-                                                                        , STR_VALUE
-                                                                        , function(selectedValue) {
-                                                                            bindSelectValueEventFunc_for(selectedValue, 
-                                                                                FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2);
-                                                                        });
+                    ,arg2
+                    ,loadedVariableNameList_arg2
+                    , VP_CLASS_STYLE_WIDTH_20PERCENT
+                    , STR_VALUE
+                    , function(selectedValue) {
+                        bindSelectValueEventFunc_for(selectedValue, 
+                            FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG2);
+                    });
                 sbforArgContainer.appendLine(sbforParamArg2);
-            }   
+            }
+            
             if (arg3 == FOR_BLOCK_ARG3_TYPE.ZIP) {
                 var sbforParamArg7 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_7 + uuid
                                                                     ,arg7
@@ -653,6 +485,7 @@ define([
                                                                     });
                 sbforArgContainer.appendLine(sbforParamArg7);
             }  
+
             if (arg3 == FOR_BLOCK_ARG3_TYPE.RANGE) {
                 var sbforParamArg6 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_6 + uuid
                                                                     , arg6
@@ -664,7 +497,8 @@ define([
                                                                             FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG6);
                                                                     });
                 sbforArgContainer.appendLine(sbforParamArg6);
-            }            
+            }      
+
             if (arg3 == FOR_BLOCK_ARG3_TYPE.DEFAULT) {
                 var sbforParamArg7 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_3_DEFAULT + uuid
                                                                     ,arg3Default
@@ -677,18 +511,7 @@ define([
                                                                     });
                 sbforArgContainer.appendLine(sbforParamArg7);
             }
-            // if (arg3 == FOR_BLOCK_ARG3_TYPE.INPUT_STR) {
-            //     var sbforParamArg7 = MakeVpSuggestInputText_apiblock(VP_ID_APIBLOCK_OPTION_FOR_ARG_3_INPUT_STR + uuid
-            //                                                         , arg3InputStr
-            //                                                         , loadedVariableNameList_arg7
-            //                                                         , VP_CLASS_STYLE_WIDTH_40PERCENT
-            //                                                         , STR_VALUE
-            //                                                         , function(selectedValue) {
-            //                                                             bindSelectValueEventFunc_for(selectedValue, 
-            //                                                                 FOR_BLOCK_SELECT_VALUE_ARG_TYPE.ARG3_INPUT_STR);
-            //                                                         });
-            //     sbforArgContainer.appendLine(sbforParamArg7);
-            // }
+
             sbforArgContainer.appendLine("</div>");
             $sbforParamDom2.append(sbforArgContainer.toString());
 
@@ -700,7 +523,7 @@ define([
             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_1 + uuid).val(arg1);
             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_2 + uuid).val(arg2);
             if (arg3 == FOR_BLOCK_ARG3_TYPE.INPUT_STR) {
-                $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid).val(STR_NULL);
+                $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid).val(STR_EMPTY);
             } else {
                 $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_3 + uuid).val(arg3);
             }
@@ -718,9 +541,10 @@ define([
             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_6 + uuid).val(arg6);
             $(VP_ID_PREFIX + VP_ID_APIBLOCK_OPTION_FOR_ARG_7 + uuid).val(arg7);
 
+            return optionContainerDom;
         }
 
-        renderThisComponent();
+        return renderThisComponent();
     };
 
     return InitForBlockOption;
