@@ -1,31 +1,21 @@
 define([
     'jquery'
     , 'nbextensions/visualpython/src/common/vpCommon'
-    , 'nbextensions/visualpython/src/common/constant'
-    , 'nbextensions/visualpython/src/common/StringBuilder'
     , 'nbextensions/visualpython/src/common/component/vpTableLayoutVerticalSimple'
 
     , '../../api.js'    
     , '../../constData.js'
     , '../base/index.js'
-], function ( $, vpCommon, vpConst, sb, vpTableLayoutVerticalSimple,
+], function ( $, vpCommon, vpTableLayoutVerticalSimple,
 
               api, constData, baseComponent ) {
 
-    const { CreateOneArrayValueAndGet
-            , UpdateOneArrayValueAndGet
+    const {  UpdateOneArrayValueAndGet
             , DeleteOneArrayValueAndGet
 
-            , RenderInputRequiredColor
-            , GenerateReturnOutParamList } = api;
+            , GenerateReturnCode } = api;
 
-    const { BLOCK_DIRECTION
-            , BLOCK_CODELINE_BTN_TYPE
-            , BLOCK_CODELINE_TYPE
-            , STR_COLON_SELECTED
-            , STR_EMPTY
-            , STR_FOR
-            , STR_INPUT
+    const { STR_EMPTY
             , STR_CLICK 
             , STR_CHANGE_KEYUP_PASTE
             
@@ -50,15 +40,13 @@ define([
         returnOutParamList.forEach((_, index ) => {
             $(document).off(STR_CHANGE_KEYUP_PASTE, `.vp-apiblock-input-param-${index}-${uuid}`);
             $(document).on(STR_CHANGE_KEYUP_PASTE, `.vp-apiblock-input-param-${index}-${uuid}`, function(event) {
-    
-                RenderInputRequiredColor(this);
 
                 var newParam = $(this).val();
                 thisBlock.setState({
                     returnOutParamList: UpdateOneArrayValueAndGet(thisBlock.getState(STATE_returnOutParamList), 
                                                                   index, newParam)
                 });
-                var returnOutParamStr = GenerateReturnOutParamList(thisBlock);
+                var returnOutParamStr = GenerateReturnCode(thisBlock);
                 thisBlock.writeCode(returnOutParamStr);
 
                 event.stopPropagation();
@@ -72,11 +60,11 @@ define([
             $(document).on(STR_CLICK, VP_ID_PREFIX + VP_CLASS_APIBLOCK_PARAM_DELETE_BTN + index + uuid, function() {
                 var inParamList = thisBlock.getState(STATE_returnOutParamList);
                 thisBlock.setState({
-                    [`${STATE_returnOutParamList}`]:  DeleteOneArrayValueAndGet(inParamList, index)
+                    [STATE_returnOutParamList]:  DeleteOneArrayValueAndGet(inParamList, index)
                 });
         
                 blockContainerThis.renderBlockOptionTab(); 
-                var inParamStr = GenerateReturnOutParamList(thisBlock);
+                var inParamStr = GenerateReturnCode(thisBlock);
                 thisBlock.writeCode(inParamStr);
             });
         });
@@ -149,10 +137,6 @@ define([
             /** bottom block option 탭에 렌더링된 dom객체 생성 */
             $(optionPageSelector).append(returnBlockOption);
 
-            returnOutParamList.forEach( (_,index) => {
-                RenderInputRequiredColor(`.vp-apiblock-input-param-${index}-${thisBlock.getUUID()}`);
-            });
-
             return returnBlockOption;
         }
 
