@@ -216,8 +216,8 @@ define([
     const NUM_OPTION_PAGE_WIDTH = 225;
 
     const NUM_BUTTONS_PAGE_WIDTH = 200;
-    const NUM_API_BOARD_CENTER_PAGE_WIDTH = 300;
-    const NUM_API_BOARD_CENTER_PAGE_MIN_WIDTH = 290;
+    const NUM_API_BOARD_CENTER_PAGE_WIDTH = 282;
+    const NUM_API_BOARD_CENTER_PAGE_MIN_WIDTH = 282;
     const NUM_TEXT_BLOCK_WIDTH = 900;
     /** ---------------------------------------- const String ------------------------------------------ */
     const STR_EMPTY = '';
@@ -431,6 +431,9 @@ define([
     const VP_BLOCK_BLOCKCODELINETYPE_CONTROL = 'vp-block-control';
     const VP_BLOCK_BLOCKCODELINETYPE_API = 'vp-block-api';
     const VP_BLOCK_BLOCKCODELINETYPE_CODE = 'vp-block-blockcodelinetype-code';
+    const VP_BLOCK_BLOCKCODELINETYPE_TEXT = 'vp-block-text';
+    const VP_BLOCK_BLOCKCODELINETYPE_NODE = 'vp-block-node';
+
     const VP_CLASS_BLOCK_NUM_INFO = 'vp-block-num-info';
     const VP_CLASS_APIBLOCK_MINIMIZE = 'vp-apiblock-minimize';
     const VP_CLASS_APIBLOCK_ARROW_UP = 'vp-apiblock-arrow-up';
@@ -898,6 +901,8 @@ define([
         , VP_BLOCK_BLOCKCODELINETYPE_CONTROL
         , VP_BLOCK_BLOCKCODELINETYPE_API
         , VP_BLOCK_BLOCKCODELINETYPE_CODE
+        , VP_BLOCK_BLOCKCODELINETYPE_TEXT
+        , VP_BLOCK_BLOCKCODELINETYPE_NODE
         
         , VP_ID_PREFIX
         , VP_ID_WRAPPER
