@@ -493,7 +493,12 @@ define([
             // 패키지인 경우 그룹 생성
             if (libObj._name != undefined) {
                 if (libObj._level == 0) {
-                    new CreateGroup(blockContainer, libObj._id, libObj._name, VP_CLASS_PREFIX + 'vp-block-group-box-api', libObj._level);
+                    var open = false;
+                    if (libObj._name == 'Common') {
+                        // Common은 처음에 열어놓고 시작
+                        open = true;
+                    }
+                    new CreateGroup(blockContainer, libObj._id, libObj._name, VP_CLASS_PREFIX + 'vp-block-group-box-api', libObj._level, open);
                 } else {
                     new CreateGroup(blockContainer, libObj._id, libObj._name, VP_CLASS_PREFIX + 'vp-apiblock-left-tab-' + parentId, libObj._level);
                 }
