@@ -102,9 +102,30 @@ define([
             $(vpCommon.formatString(".{0}", that._UUID)).remove();
         });
 
+        /** esc shortcut add */
+        $(document).bind(vpCommon.formatString('keydown.{0}', that._UUID), function(event) {
+            that.handleEscToExit(event);
+        });
+
         $(sbTagString.toString()).appendTo("body");
     }
 
+    /**
+     * ESC키로 창 닫기
+     * @param {Event} event 
+     */
+    vpMultiButtonModal.prototype.handleEscToExit = function(event) {
+        var keyCode = event.keyCode ? event.keyCode : event.which;
+        // esc
+        if (keyCode == 27) {
+            console.log('esc from modal', this._UUID);
+
+            $(document).unbind(vpCommon.formatString(".{0}", this._UUID));
+            $(vpCommon.formatString(".{0}", this._UUID)).remove();
+            $(vpCommon.formatString("keydown.{0}", this._UUID), this.handleEscToExit);
+        }
+    }
+
     return {
         vpMultiButtonModal: vpMultiButtonModal
     }
