@@ -42,20 +42,29 @@ define([
         sbTagString.appendFormatLine("<div class='{0} {1}' {2}>"
             , that._UUID, vpConst.TAB_CONTAINER, that._tabID == "" ? "" : vpCommon.formatString("id='{0}'", that._tabID));
 
-        sbTagString.appendFormatLine("<ul class='{0}'>", vpConst.TAB_HEAD_CONTROL);
-        for (tabIdx = 0; tabIdx < that._tabPages.length; tabIdx++) {
-            sbTagString.appendFormatLine("<li class='{0}' rel='{1}'>{2}</li>"
-                , tabIdx == 0 ? "active" : "", that._tabPages[tabIdx].get("pageid"), that._tabPages[tabIdx].get("caption"));
-        }
-        sbTagString.appendLine("</ul>");
+        /** 2021 01 17 장안태 팀장 코드 주석 처리 */
+        // sbTagString.appendFormatLine("<ul class='{0}'>", vpConst.TAB_HEAD_CONTROL);
+        // for (tabIdx = 0; tabIdx < that._tabPages.length; tabIdx++) {
+        //     sbTagString.appendFormatLine("<li class='{0}' rel='{1}'>{2}</li>"
+        //         , tabIdx == 0 ? "active" : "", that._tabPages[tabIdx].get("pageid"), that._tabPages[tabIdx].get("caption"));
+        // }
 
+        sbTagString.appendLine("</ul>");
         sbTagString.appendFormatLine("<div class='{0}{1}'>", vpConst.VP_CLASS_PREFIX, "tab-content");
         
+        /** 2021 01 17 이진용 주임 추가 */
         for (tabIdx = 0; tabIdx < that._tabPages.length; tabIdx++) {
             sbTagString.appendFormatLine("<div class='{0}{1}' {2} id='{3}'></div>"
-                ,vpConst.VP_CLASS_PREFIX, "tab-page", tabIdx == 0 ? "" : "style='display: none;'", that._tabPages[tabIdx].get("pageid"));
+                ,vpConst.VP_CLASS_PREFIX, "tab-page", tabIdx == 1 ? "" : "style='display: none;'", that._tabPages[tabIdx].get("pageid"));
         }
 
+        /** 2021 01 17 장안태 팀장 코드 주석 처리 */
+        // for (tabIdx = 0; tabIdx < that._tabPages.length; tabIdx++) {
+        //     sbTagString.appendFormatLine("<div class='{0}{1}' {2} id='{3}'></div>"
+        //         ,vpConst.VP_CLASS_PREFIX, "tab-page", tabIdx == 0 ? "" : "style='display: none;'", that._tabPages[tabIdx].get("pageid"));
+        // }
+
+
         sbTagString.appendLine("</div>");
 
         sbTagString.appendLine("</div>");
