@@ -30,7 +30,6 @@ define([
      @param {funcOptProp} props 기본 속성
      */
     VpFuncJS.prototype.setOptionProp = function(props) {
-        this.stepCount = props.stepCount;
         this.funcName = props.funcName;
         this.funcID = props.funcID;
     }
@@ -244,6 +243,22 @@ define([
         }
     }
 
+    /**
+     * Get Value of Metadata by option id
+     * @param {string} id 
+     */
+    VpFuncJS.prototype.getMetadata = function(id) {
+        if (this.metadata == undefined)
+            return "";
+        var len = this.metadata.options.length;
+        for (var i = 0; i < len; i++) {
+            var obj = this.metadata.options[i];
+            if (obj.id == id)
+                return obj.value;
+        }
+        return "";
+    }
+
     /**
      * 페이지 내용 삽입.
      * @param {String} content 페이지 내용
@@ -381,11 +396,9 @@ define([
      */
     VpFuncJS.prototype.openMultiBtnModal = function(message = "", buttons = new Array(), callback) {
         var mbmModal = new vpMultiButtonModal.vpMultiButtonModal();
-
         mbmModal.setMessage(message);
         mbmModal.setButtons(buttons);
         mbmModal.openModal(callback);
-        // console.log('mbmModal',mbmModal);
     }
 
     /**
@@ -396,11 +409,7 @@ define([
      */
     VpFuncJS.prototype.openMultiBtnModal_new = function(message = "", submessage, buttons = new Array(), callbackList) {
         var mbmModal = new vpMultiButtonModal_new.vpMultiButtonModal(message, submessage, buttons, callbackList);
-
-        // mbmModal.setMessage(message);
-        // mbmModal.setButtons(buttons);
         mbmModal.openModal(callbackList);
-        // console.log('mbmModal',mbmModal);
     }
     return {'VpFuncJS': VpFuncJS};
 });
\ No newline at end of file
