@@ -260,7 +260,7 @@ define([
         var xmlSettings = new xmlHandler.VpXMLHandler(vpSettingsUrl);
         xmlSettings.loadFile(function() {
             var xml = xmlSettings.getXML();
-            console.log(xml);
+            // console.log(xml);
             settingsLoadCallback(xml, callback);
         });
     };
@@ -269,7 +269,7 @@ define([
         var xmlSettings = new xmlHandler.VpXMLHandler(vpSettingsUrl);
         xmlSettings.loadFile(function() {
             var json = xmlSettings.getJson();
-            console.log(json);
+            // console.log(json);
             settingsLoadCallback(json, callback);
         });
     }
