@@ -536,9 +536,6 @@ define([
         var sbPageContent = new sb.StringBuilder();
         var sbTagString = new sb.StringBuilder();
 
-        // prefix code 입력 영역
-        sbPageContent.appendLine(this.createManualCode(vpConst.API_OPTION_PREFIX_CAPTION, vpConst.API_OPTION_PREFIX_CODE_ID));
-
         // 필수 옵션 테이블 레이아웃
         var tblLayoutRequire = this.createVERSimpleLayout("10%");
         tblLayoutRequire.addClass(vpConst.OPTION_TABLE_LAYOUT_HEAD_HIGHLIGHT);
@@ -605,9 +602,6 @@ define([
 
         sbPageContent.appendLine(accBoxRequire.toTagString());
 
-        // postfix code 입력 영역
-        sbPageContent.appendLine(this.createManualCode(vpConst.API_OPTION_POSTFIX_CAPTION, vpConst.API_OPTION_POSTFIX_CODE_ID));
-
         // 페이지에 컨트롤 삽입 vpFuncJS 에서 제공
         $(this.wrapSelector('#vp_pipCommandPage')).html(sbPageContent.toString());
 
@@ -757,8 +751,6 @@ define([
      */
     PipPackage.prototype.generateCode = function(addCell = false, exec = false) {
         var code = new sb.StringBuilder();
-
-        code.appendFormatLine('{0}', $(this.wrapSelector('#' + vpConst.API_OPTION_PREFIX_CODE_ID)).val());
         
         // code from user input
         var inputs = $(this.wrapSelector('.vp-pip-table tr:not(:last)'));
@@ -789,8 +781,6 @@ define([
         // save column metadata
         $(this.wrapSelector('#vp_pipMeta')).val(encodeURIComponent(JSON.stringify(pipMeta)));
 
-        code.appendFormat('{0}', $(this.wrapSelector('#' + vpConst.API_OPTION_POSTFIX_CODE_ID)).val());
-
         if (addCell) {
             this.cellExecute(code.toString(), exec);
         }
