@@ -164,15 +164,9 @@ define([
      * @param {boolean} exec 실행여부
      */
     MatplotPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
         
-        // add prefix code
-        var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
-        if (prefixCode.length > 0) {
-            sbCode.appendLine(prefixCode);
-        }
         
         // Figure 변수명
         var figure = $(this.wrapSelector('#figureVar')).val();
@@ -190,12 +184,6 @@ define([
         // cell metadata 작성하기
         // pdGen.vp_setCellMetadata(_VP_CODEMD);
 
-        // add postfix code
-        var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
-        if (postfix.length > 0) {
-            sbCode.appendLine('');
-            sbCode.append(postfix);
-        }
 
         if (addCell) this.cellExecute(sbCode.toString(), exec);
 
