@@ -310,16 +310,21 @@ define([
     var vp_searchVarList = function(types, callback) {
         // types에 맞는 변수목록 조회하는 명령문 구성
         var cmdSB = new sb.StringBuilder();
-        cmdSB.appendLine('import json');
-        cmdSB.append(`print(json.dumps([{'varName': v, 'varType': type(eval(v)).__name__}`);
-        cmdSB.append(`for v in dir() if (not v.startswith('_')) `);
-        cmdSB.appendFormat('& (v not in {0})', JSON.stringify(_VP_NOT_USING_VAR));
+        // cmdSB.appendLine('import json');
+        // cmdSB.append(`print(json.dumps([{'varName': v, 'varType': type(eval(v)).__name__}`);
+        // cmdSB.append(`for v in dir() if (not v.startswith('_')) `);
+        // cmdSB.appendFormat('& (v not in {0})', JSON.stringify(_VP_NOT_USING_VAR));
+        // if (types != undefined && types.length > 0) {
+        //     cmdSB.appendFormat(`& (type(eval(v)).__name__ in {0})`, JSON.stringify(types));
+        // } else {
+        //     cmdSB.appendFormat(`& (type(eval(v)).__name__ not in {0}) `, JSON.stringify(_VP_NOT_USING_TYPE));
+        // }
+        // cmdSB.append(']))');
         if (types != undefined && types.length > 0) {
-            cmdSB.appendFormat(`& (type(eval(v)).__name__ in {0})`, JSON.stringify(types));
+            cmdSB.appendFormat('_vp_print(_vp_get_variables_list({0}))', JSON.stringify(types));
         } else {
-            cmdSB.appendFormat(`& (type(eval(v)).__name__ not in {0}) `, JSON.stringify(_VP_NOT_USING_TYPE));
+            cmdSB.appendFormat('_vp_print(_vp_get_variables_list({0}))', 'None');
         }
-        cmdSB.append(']))');
 
         // FIXME: vpFuncJS에만 kernel 사용하는 메서드가 정의되어 있어서 임시로 사용
         vp_executePython(cmdSB.toString(), function(result) {
@@ -600,9 +605,10 @@ define([
         }
 
         var code = new sb.StringBuilder();
-        code.appendLine('import json');
-        code.appendFormat(`print(json.dumps([ { "value": ("'" + c + "'") if type(c).__name__ == 'str' else c, "label": c, "dtype": str({0}[c].dtype), "array": str({1}[c].array) } for c in list({2}.columns) ]))`
-                        , varName, varName, varName);
+        // code.appendLine('import json');
+        // code.appendFormat(`print(json.dumps([ { "value": ("'" + c + "'") if type(c).__name__ == 'str' else c, "label": c, "dtype": str({0}[c].dtype), "array": str({1}[c].array) } for c in list({2}.columns) ]))`
+        //                 , varName, varName, varName);
+        code.appendFormat('_vp_print(_vp_get_columns_list({0}))', varName);
         // get result and show on detail box
         pageThis.kernelExecute(code.toString(), function(result) {
             try {
