@@ -21,7 +21,8 @@ define([
     }
 
     const FILE_NAVIGATION_TYPE = {
-        SAVE_FILE: 'SAVE_FILE'
+        SAVE_FILE: 'SAVE_FILE',
+        READ_IMG_FOR_MARKDOWN: 'READ_IMG_FOR_MARKDOWN'
     }
 
     /**
