@@ -14,7 +14,7 @@ define([
               executor) {
 
     const { executeKernelFromDirBody } = executor;
-    const { NAVIGATION_DIRECTION_TYPE } = constData;
+    const { NAVIGATION_DIRECTION_TYPE, FILE_NAVIGATION_TYPE } = constData;
 
     // 옵션 속성
     const funcOptProp = {
@@ -34,6 +34,10 @@ define([
         fileNavigationState.setFileOptionData(importPackageThis.state);
         fileNavigationState.setImportPackageThis(importPackageThis);
         fileNavigationState.setFileNavigationtype(type);
+        // FIXME: 마크다운 이미지 불러오기 일 경우, 완료 트리거 설정
+        if (type == FILE_NAVIGATION_TYPE.READ_IMG_FOR_MARKDOWN) {
+            fileNavigationState.setTriggerName(importPackageThis.triggerName);
+        }
         fileNavigationRenderer = new FileNavigationRenderer(fileNavigationState, vpFuncJS, importPackageThis.fileResultState);
 
         vpFuncJS.kernelExecuteV2(`%pwd`,(currentDirStr) => {
@@ -113,25 +117,57 @@ define([
         // 파일네비게이션을 닫았을때 실행되는 click 함수
         $('.fileNavigationPage-closedBtn').click(() => {
             fileNavigationState.resetStack();
-            $('#vp_fileNavigation').addClass("hide");
-            $('#vp_fileNavigation').removeClass("show");
             $('#vp_fileNavigation').remove();
             
             // 파일 네비게이션에서 생성된 script 파일 삭제
             vpCommon.removeHeadScript("fileNavigation");
-            vpCommon.removeHeadScript("loadingBar");
-            vpCommon.removeHeadScript("successMessage");
-            vpCommon.removeHeadScript("yesOrNoModal");
+            // vpCommon.removeHeadScript("successMessage");
+        });
+
+        // 사이드바 선택
+        $('.fnp-sidebar-menu').click(function(event) {
+            $('.fnp-sidebar-menu').removeClass('selected');
+            $(this).addClass('selected');
+
+            var pathType = $(this).attr('data-path');
+            var dirObj = {
+                direction: NAVIGATION_DIRECTION_TYPE.TO,
+                destDir: '/'
+            }
+            switch (pathType) {
+                case '/':
+                    dirObj.direction = NAVIGATION_DIRECTION_TYPE.TOP;
+                    break;
+                case 'desktop':
+                    dirObj.destDir = "_vp_get_desktop_path()";
+                    dirObj.useFunction = true;
+                    break;
+                case 'documents':
+                    dirObj.destDir = "_vp_get_documents_path()";
+                    dirObj.useFunction = true;
+                    break;
+                case 'downloads':
+                    dirObj.destDir = "_vp_get_downloads_path()";
+                    dirObj.useFunction = true;
+                    break;
+                case 'userid':
+                    dirObj.destDir = "_vp_get_userprofile_path()";
+                    dirObj.useFunction = true;
+                    break;
+            }
+            executeKernelFromDirBody(dirObj, fileNavigationRenderer);
         });
     
-        // 상위 디렉토리 클릭시 실행되는 함수
-        $('.fileNavigationPage-btn-up').click(() => {
-
+        // 다음(>) 디렉토리 클릭시 실행되는 함수
+        $('.fileNavigationPage-btn-next').click(() => {
             if (fileNavigationState.stackCursor + 1 == fileNavigationState.getDirHistoryStack().length) {
                 vpCommon.renderAlertModal('No next directory');
                 return;
             }
 
+            // initialize sidebar-menu selection
+            $('.fnp-sidebar-menu').removeClass('selected');
+
             fileNavigationState.stackCursor++;
 
             var nextData = fileNavigationState.getNextDirHistoryStack();
@@ -143,13 +179,16 @@ define([
             executeKernelFromDirBody(dirObj, fileNavigationRenderer);
         });
     
-        // 이전 디렉토리 검색 클릭시 실행되는 함수
+        // 이전(<) 디렉토리 검색 클릭시 실행되는 함수
         $('.fileNavigationPage-btn-prev').click(() => {
-
             if (fileNavigationState.stackCursor <= 0) {
                 vpCommon.renderAlertModal('No previous directory');
                 return;
             }
+
+            // initialize sidebar-menu selection
+            $('.fnp-sidebar-menu').removeClass('selected');
+
             fileNavigationState.stackCursor--;
 
             var popedData = fileNavigationState.popDirHistoryStackAndGetPopedData();
