@@ -11,15 +11,15 @@ define([
 ], function ( requirejs, $, vpCommon, vpMakeDom, sb,
               componentConstApi, executor, constData) {
 
-    const { NAVIGATION_DIRECTION_TYPE } = constData;
+    const { NAVIGATION_DIRECTION_TYPE
+            , FILE_NAVIGATION_TYPE } = constData;
+
     // kernel executor에 필요한 함수 import
-    const { executeKernelFromDir,
-            executeKernelFromDirBody } = executor;
+    const { executeKernelFromDirBody } = executor;
+
     // dom 만드는데 필요한 함수 import
     const { controlToggleInput } = componentConstApi;
     const { renderSpan, renderLi } = vpMakeDom;
-    // stringBuilder import
-    // var sbCode = new sb.StringBuilder();
 
     var FileNavigationRenderer = function(fileNavigationState, vpFuncJS, fileResultState) {
         this.fileNavigationState = fileNavigationState;
@@ -37,8 +37,6 @@ define([
         var dirObj = {
             direction: NAVIGATION_DIRECTION_TYPE.INIT,
         }
- 
-        executeKernelFromDir(dirObj, fileNavigationRendererThis);
 
         /** fileNavigation right tab에 현재 path의 폴더와 파일들 렌더링 */
         executeKernelFromDirBody(dirObj, fileNavigationRendererThis);
@@ -49,17 +47,16 @@ define([
         var fileOptionData = fileNavigationState.getFileOptionData();
 
         /** Pandas > File IO > to_csv(), to_excel(), to_json(), to_pickle() 네비게이션 클릭시 */
-        if(fileNavigationtype === 'SAVE_FILE'){
-
-            /** 20201118 이진용 주임 수정 */
-            /** 현재 디렉토리에 파일 저장 -> Save file to current directory */
-            /** 파일 이름 입력 -> Input file name */
+        if(fileNavigationtype == FILE_NAVIGATION_TYPE.SAVE_FILE){
             var saveFileDataBtn = $(`<button class='fileNavigationPage-btn-saveVisualPython'
-                                                 style='margin-left: 10px;'>Save file to current directory</button>`);
+                                             style='margin-left: 10px;'>Save</button>`);
+            var cancelFileDataBtn = $(`<button class='fileNavigationPage-btn-cabcelVisualPython'
+                                               style='margin-left: 10px;'>Cancel</button>`);
             var saveFileDataInput = $(`<input id='vp-fileNavigation' type='text' placeholder='Input file name'></input>`);
-            $('.fileNavigationPage-savebutton').append(saveFileDataInput);
-            $('.fileNavigationPage-savebutton').append(saveFileDataBtn);
-         
+            $('.fileNavigationPage-button').append(saveFileDataInput);
+            $('.fileNavigationPage-button').append(saveFileDataBtn);
+            $('.fileNavigationPage-button').append(cancelFileDataBtn);
+
             controlToggleInput();
             $(saveFileDataInput).on('change keyup paste', function() {
                 fileNavigationState.setVisualPythonFileName($(this).val());
@@ -70,8 +67,6 @@ define([
              */
             $(saveFileDataBtn).click(function(){
                 if(fileNavigationState.getVisualPythonFileName() === ``){
-                    /** 20201118 이진용 주임 수정 */
-                    /** File 이름을 입력해주세요 -> Please input file name */
                     vpCommon.renderAlertModal('Please input file name');
                     return;
                 }
@@ -85,30 +80,23 @@ define([
                 fileNavigationRendererThis.selectFile(dirPath, fileName);
                 fileNavigationState.resetStack();
             });
+
+            $(cancelFileDataBtn).click(function(){
+                fileNavigationState.resetStack();
+                $('#vp_fileNavigation').remove();
+                
+                // 파일 네비게이션에서 생성된 script 파일 삭제
+                vpCommon.removeHeadScript("fileNavigation");
+            });
         }
     }
 
-    /** */
-    FileNavigationRenderer.prototype.renderCurrentDirPathInfo = function(dirInfoArr) {
-        $('.fileNavigationPage-directory-container').empty();
-
-        var currentDirRootDom = $(`<div class='fileNavigationPage-right'>
-                                  </div>`);
-        var { folderArr } = this.makeFolderOrFileDomArr(dirInfoArr);
-    
-        currentDirRootDom.appendTo('.fileNavigationPage-directory-container');
-        var fileNavigationPageUl = $('.fileNavigationPage-ul');
-        folderArr.forEach(dom => {
-            fileNavigationPageUl.append(dom);
-        });
-    }
-
     /** */
     FileNavigationRenderer.prototype.renderCurrentDirPathInfoRightBody = function(dirInfoArr) {
-        $('.fileNavigationPage-right').empty();
-        var currentDirRootDom = $(`<div class='fileNavigationPage-body'></div>`);
+     
+        $('.fileNavigationPage-body').empty();
+        var currentDirRootDom = $('.fileNavigationPage-body');
         var { folderArr, fileArr } = this.makeFolderOrFileDomArr(dirInfoArr);
-        
         var fileNavigationPageUl = $(`<ul class='fileNavigationPage-ul'>
                                       </ul>`);
   
@@ -119,10 +107,11 @@ define([
             fileNavigationPageUl.append(dom);
         });
         currentDirRootDom.append(fileNavigationPageUl);
-        currentDirRootDom.appendTo('.fileNavigationPage-right');
     }
 
-    /** <div/> 태그 형식의 폴더 디렉토리를 만드는 함수 */
+    /** <div/> 태그 형식의 폴더 디렉토리를 만드는 함수 
+     * @param {JSON} node
+    */
     FileNavigationRenderer.prototype.makeFolderDom = function(node) {
         var fileNavigationRendererThis = this;
 
@@ -142,6 +131,10 @@ define([
                 direction: NAVIGATION_DIRECTION_TYPE.TO,
                 destDir: folderPath
             }
+
+            // initialize sidebar-menu selection
+            $('.fnp-sidebar-menu').removeClass('selected');
+
             executeKernelFromDirBody(dirObj, fileNavigationRendererThis);
         });
 
@@ -149,7 +142,9 @@ define([
         return directoryLi;
     }
 
-    /**  <div/> 태그 형식의 파일 디렉토리를 만드는 함수 */
+    /**  <div/> 태그 형식의 파일 디렉토리를 만드는 함수
+     * @param {JSON} node 
+     */
     FileNavigationRenderer.prototype.makeFileDom = function(node) {
         var that = this;
         var fileNavigationState = this.getFileNavigationState();
@@ -165,11 +160,22 @@ define([
         directoryI.click(function() {
             var dirPath = that.makeNewCurrRelativePath();
             var dataOption = fileNavigationState.getFileOptionData();
-            if (fileName.indexOf('.' + dataOption.fileExtension) === -1) {
-                vpCommon.renderAlertModal('Not ' + dataOption.fileExtension + ' file');
-                return;
+            var extension = fileName.substring(fileName.lastIndexOf('.') + 1);
+            if (Array.isArray(dataOption.fileExtension)) {
+                // 확장자 여러개 입력되었을 경우
+                // 확장자 목록에 포함되어있지 않을 경우
+                if (!dataOption.fileExtension.includes(extension)) {
+                    vpCommon.renderAlertModal('Not supported file type');
+                    return;
+                }
+            } else {
+                // Deprecated: 여러 항목 명시하지 않는 경우, 확장자 체크 제외
+                // 확장자가 맞지 않는 경우
+                // if (extension != dataOption.fileExtension) {
+                //     vpCommon.renderAlertModal('Not ' + dataOption.fileExtension + ' file');
+                //     return;
+                // }
             }
-
             that.selectFile(dirPath, fileName);
         });
 
@@ -249,27 +255,9 @@ define([
         return dirPath;
     }
 
-    // loadingBar를 생성합니다.
-    FileNavigationRenderer.prototype.startLoadingBar = function() {
-        // $('.fileNavigationPage-directory-container').empty();
-        // this.renderLoadingBar();
-    }
-
-    // loadingBar를 종료합니다.
-    FileNavigationRenderer.prototype.finishLoadingBarAndSetCurrDirStr = function(currentDirStr, currentRelativePathStr) {
-        var fileNavigationRendererThis = this;
-        fileNavigationRendererThis.fileNavigationState.setRelativeDir(currentRelativePathStr);
-        fileNavigationRendererThis.fileNavigationState.setCurrentDir(currentDirStr);
-
-        // $('.fileNavigationPage-directory-container').find('#vp_loadingBar').remove();
-    }
-
-    // 로딩을 생성하는 함수
-    FileNavigationRenderer.prototype.renderLoadingBar = function() {
-        // vpCommon.renderLoadingBar();
-    }
-
-    /** */
+    /**
+     *  파일 네비게이션 위에 / Desktop / Bit Python 이런식으로 현재 디렉토리의 정보를 보여주는 메소드
+     */
     FileNavigationRenderer.prototype.renderNowLocation = function(currentDirStr, currentRelativePathStr) {
         /** 이 메소드에서 사용할 state 데이터 가져오기 */
         var fileNavigationRendererThis = this;
@@ -297,6 +285,10 @@ define([
                 direction: NAVIGATION_DIRECTION_TYPE.TO,
                 destDir: notebookPathStr
             }
+            
+            // initialize sidebar-menu selection
+            $('.fnp-sidebar-menu').removeClass('selected');
+
             // fileNavigation body에 현재 path의 폴더와 파일들 렌더링
             executeKernelFromDirBody(dirObj, fileNavigationRendererThis);
         });
@@ -309,7 +301,9 @@ define([
                 slashStr = '/';
             }
 
-            var spanElement = $(`<span class='vp-filenavigation-nowLocation' value='${pathToken}'> ${slashStr} ${pathToken} </span>`);
+            var spanElement = $(`<span class='vp-filenavigation-nowLocation' value='${pathToken}'> 
+                                    ${slashStr} ${pathToken}
+                                </span>`);
             var pathLength = notebookPathStrLength + pathToken.length + 1 + nestedLength;
             spanElement.click(function() {
                 var currentRelativePathStr = `${currentDirStr.substring(0, pathLength)}`;
@@ -318,6 +312,9 @@ define([
                     direction: NAVIGATION_DIRECTION_TYPE.TO,
                     destDir: currentRelativePathStr
                 }
+
+                // initialize sidebar-menu selection
+                $('.fnp-sidebar-menu').removeClass('selected');
              
                 // fileNavigation body에 현재 path의 폴더와 파일들 렌더링
                 executeKernelFromDirBody(dirObj, fileNavigationRendererThis);
@@ -408,7 +405,7 @@ define([
         // vpCommon.renderSuccessMessage(filePathStr + ' selection ' + 'completed');
         
         /** 장안태 추가. 파일 선택 완료시 문서 이벤트 발동 */
-        if (fileNavigationState.getFileNavigationtype() === 'SAVE_FILE') {
+        if (fileNavigationState.getFileNavigationtype() === FILE_NAVIGATION_TYPE.SAVE_FILE) {
             $(document).trigger({
                 type:"fileSaveSelected.fileNavigation",
                 path:`${filePathStr}`
@@ -419,14 +416,20 @@ define([
                 path:`${filePathStr}`
             });
         }
+
+        /** 김민주 추가. Markdown 이미지 파일 선택 완료시 이벤트 발동 */
+        // imgFileOpenForMarkdown.fileNavigation
+        if (fileNavigationState.getFileNavigationtype() === FILE_NAVIGATION_TYPE.READ_IMG_FOR_MARKDOWN) {
+            $(document).trigger({
+                type: fileNavigationState.getTriggerName(),
+                path: `${filePathStr}`
+            })
+        }
    
-        $('#vp_fileNavigation').addClass('hide');
-        $('#vp_fileNavigation').removeClass('show');
         $('#vp_fileNavigation').remove();
         
         // 파일 네비게이션에서 생성된 script 파일 삭제
         vpCommon.removeHeadScript('fileNavigation');
-        vpCommon.removeHeadScript('loadingBar');
     }
 
     return FileNavigationRenderer;
