@@ -67,7 +67,7 @@ define([
             input: [
                 {
                     name: 'i0',
-                    label: 'pandas as',
+                    label: 'Pandas As',
                     type: 'int',
                     value: 'pd'
                 }
@@ -119,7 +119,7 @@ define([
      */
     PandasPackage.prototype.bindOptions = function() {
         // HTML 구성
-        pdGen.vp_showInterface(this.wrapSelector(''), this.package);
+        pdGen.vp_showInterface(this);
         // if it has no additional options, remove that box
         if (this.package.variable == undefined || this.package.variable.length <= 0) {
             $(this.wrapSelector('#vp_optionBox')).closest('div.vp-accordion-container').remove();
@@ -134,7 +134,6 @@ define([
      * @param {boolean} exec 실행여부
      */
     PandasPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
         
