@@ -78,10 +78,9 @@ define([
      */
     PandasPackage.prototype.initHtml = function() {
         this.showFunctionTitle();
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
 
         this.bindOptions();
-
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
     }
 
     /**
@@ -104,7 +103,16 @@ define([
         this.package.input[0].options = optionsPath;
 
         // HTML 구성
-        pdGen.vp_showInterface(this.wrapSelector(''), this.package);
+        pdGen.vp_showInterface(this);
+
+        // get metadata - sample file
+        if (this.metadata) {
+            var sampleType = this.getMetadata('i0');
+            if (sampleType) {
+                $(this.wrapSelector('#i0')).val(sampleType);
+            }
+        }
+
         // if it has no additional options, remove that box
         if (this.package.variable == undefined || this.package.variable.length <= 0) {
             $(this.wrapSelector('#vp_optionBox')).closest('div.vp-accordion-container').remove();
@@ -131,12 +139,6 @@ define([
         var that = this;
         
         var bgCode = new sb.StringBuilder();
-
-        // add prefix code
-        var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
-        if (prefixCode.length > 0) {
-            bgCode.appendLine(prefixCode);
-        }
         
         // 코드 생성
         var result = pdGen.vp_codeGenerator(this.uuid, this.package);
@@ -152,18 +154,10 @@ define([
 /*
         // 코드 실행
         var sbCode = new sb.StringBuilder();
-        // 생성된 것 표시
-        sbCode.appendLine(`# Auto-Generated by VisualPython`);
         // 완료된 dataframe 조회
         var outputVariable = $(this.wrapSelector('#'+this.package.output[0].name)).val();
         sbCode.appendFormat('{0}', outputVariable);
 */
-        // add postfix code
-        var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
-        if (postfix.length > 0) {
-            bgCode.appendLine('');
-            bgCode.append(postfix);
-        }
 
         if (addCell) this.cellExecute(bgCode.toString(), exec);
 
