@@ -118,10 +118,28 @@ define([
      */
     PandasPackage.prototype.initHtml = function() {
         this.showFunctionTitle();
+        
+        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
+
+        // get metadata - fileType
+        if (this.metadata) {
+            var fileType = this.getMetadata('fileType');
+            if (fileType) {
+                console.log('fileType : '+fileType);
+                this.selectedFileType = fileType;
+                this.package = { ...libPandas._PANDAS_FUNCTION[this.fileTypeId[fileType]] };
+                this.state.fileExtension = this.fileExtensions[fileType];
+
+                if (fileType == 'json') {
+                    this.fileResultState.pathInputId = this.wrapSelector('#path_or_buf');
+                } else {
+                    this.fileResultState.pathInputId = this.wrapSelector('#i1');
+                }
+            }
+        }
 
         this.bindOptions();
 
-        this.loadCss(Jupyter.notebook.base_url + vpConst.BASE_PATH + vpConst.STYLE_PATH + "pandas/commonPandas.css");
     }
 
     /**
@@ -142,7 +160,7 @@ define([
         $(this.wrapSelector('#vp_optionBox table')).html('<colgroup><col width="30%"/><col width="*"/></colgroup>');
 
         // HTML 구성
-        pdGen.vp_showInterface(this.wrapSelector(''), this.package);
+        pdGen.vp_showInterface(this);
         // if it has no additional options, remove that box
         if (this.package.variable == undefined || this.package.variable.length <= 0) {
             $(this.wrapSelector('#vp_optionBox')).closest('div.vp-pandas-block').hide();
@@ -152,7 +170,7 @@ define([
 
         // 파일 유형 선택지 구성
         $(this.wrapSelector('#vp_inputOutputBox table')).prepend(
-            $('<tr>').append($('<td><label for="fileType">* file type</label></td>'))
+            $('<tr>').append($(`<td><label for="fileType" class="${vpConst.COLOR_FONT_ORANGE}">File Type</label></td>`))
                 .append($('<td><select id="fileType" class="vp-select"></select></td>'))
         );
         var fileTypeList = Object.keys(this.fileTypeId);
@@ -170,7 +188,7 @@ define([
             that.state.fileExtension = that.fileExtensions[value];
             that.selectedFileType = value;
 
-            if (value == 'Json') {
+            if (value == 'json') {
                 that.fileResultState.pathInputId = that.wrapSelector('#path_or_buf');
             } else {
                 that.fileResultState.pathInputId = that.wrapSelector('#i1');
@@ -182,15 +200,19 @@ define([
         });
 
         // 파일 네비게이션 버튼 추가
-        if (this.selectedFileType == 'Json') {
+        if (this.selectedFileType == 'json') {
             $(this.fileResultState.pathInputId).parent().html(
-                `<input type="text" class="vp-input input-single" id="path_or_buf" index="0" placeholder="" value="" title="">
-                <input type="button" value="파일 경로" class="vp-navi-btn black" id="vp_openFileNavigationBtn"><span id="fileName"></span>`
+                // `<input type="text" class="vp-input input-single" id="path_or_buf" index="0" placeholder="" value="" title="">
+                // <input type="button" value="" class="vp-navi-btn black" id="vp_openFileNavigationBtn"><span id="fileName"></span>`
+                vpCommon.formatString('<input type="text" class="vp-input input-single" id="path_or_buf" index="0" placeholder="" value="" title=""><div id="vp_openFileNavigationBtn" class="{0}"></div>'
+                , vpConst.FILE_BROWSER_INPUT_BUTTON)
             );
         } else {
             $(this.fileResultState.pathInputId).parent().html(
-                `<input type="text" class="vp-input input-single" id="i1" index="0" placeholder="" value="" title="">
-                <input type="button" value="파일 경로" class="vp-navi-btn black" id="vp_openFileNavigationBtn"><span id="fileName"></span>`
+                // `<input type="text" class="vp-input input-single" id="i1" index="0" placeholder="" value="" title="">
+                // <input type="button" value="파일 경로" class="vp-navi-btn black" id="vp_openFileNavigationBtn"><span id="fileName"></span>`
+                vpCommon.formatString('<input type="text" class="vp-input input-single" id="i1" index="0" placeholder="" value="" title=""><div id="vp_openFileNavigationBtn" class="{0}"></div>'
+                , vpConst.FILE_BROWSER_INPUT_BUTTON)
             );
         }
 
@@ -224,32 +246,22 @@ define([
      * @param {boolean} exec 실행여부
      */
     PandasPackage.prototype.generateCode = function(addCell, exec) {
-        if (!this.optionValidation()) return;
         
         var sbCode = new sb.StringBuilder();
         
-        // add prefix code
-        var prefixCode = $(this.wrapSelector('#vp_prefixBox textarea')).val();
-        if (prefixCode.length > 0) {
-            sbCode.appendLine(prefixCode);
-        }
-
-        this.package.input.push({
+        var package = JSON.parse(JSON.stringify(this.package));
+        package.input.push({
             name: 'fileType',
             type: 'var'
         });
+
+        this.package = package;
         
         // 코드 생성
-        var result = pdGen.vp_codeGenerator(this.uuid, this.package);
+        var result = pdGen.vp_codeGenerator(this.uuid, package);
         if (result == null) return "BREAK_RUN"; // 코드 생성 중 오류 발생
         sbCode.append(result);
 
-        // add postfix code
-        var postfix = $(this.wrapSelector('#vp_postfixBox textarea')).val();
-        if (postfix.length > 0) {
-            sbCode.appendLine('');
-            sbCode.append(postfix);
-        }
 
         if (addCell) this.cellExecute(sbCode.toString(), exec);
 
