@@ -505,15 +505,23 @@
      */
     var read_kernel_functions = function() {
         // FIXME: 여러 개 파일 받아올 것도 고려해야 함
-        var libName = Jupyter.notebook.base_url + "nbextensions/visualpython/src/api/functions/getPath.py";
-        $.get(libName).done(function(data) {
-            var code_init = data;
-            Jupyter.notebook.kernel.execute(code_init, { iopub: { output: function(data) {
-                console.log('visualpython - loaded library', data);
-            } } }, { silent: false });
-        }).fail(function() {
-            console.log('visualpython - failed to load getPath library');
-        });
+
+        var libraryList = [ 
+            "functions/printCommand.py"
+            , "functions/fileNaviCommand.py"
+            , "functions/pandasCommand.py"
+        ];
+        libraryList.forEach(libName => {
+            var libPath = Jupyter.notebook.base_url + "nbextensions/visualpython/src/api/" + libName
+            $.get(libPath).done(function(data) {
+                var code_init = data;
+                Jupyter.notebook.kernel.execute(code_init, { iopub: { output: function(data) {
+                    console.log('visualpython - loaded library', data);
+                } } }, { silent: false });
+            }).fail(function() {
+                console.log('visualpython - failed to load getPath library');
+            });
+        })
     }
 
     /**
